#!/bin/sh
#
# Setup.sh, Hybrid7+mpb - Michael P. Bramel mbramel@fuse.net
# This is the beginnings of my setup script. It will use the sh command interpreter.
# In it's earliest stages it will be included with the hybrid mpb release, but will
# not be listed as a feature until i'm satisfied that it's been completed.
# For now be weary when you use it, as it may or may not work correctly.
#
# Step 1 - Gather precompile information from the user.
# Here we get the variables required to pass to the configure command line
# We also get some information to put our config.h together.
#
echo ""
echo "Hybrid7+MPB Setup Utility version 1.01 Running."
echo "------------------------------------------------------"
echo "This lil program semi-automates several things. First"
echo "and foremost it creates a config.h with options based"
echo "on user input. It will also proceed through the configure"
echo "make and make install steps. This file will obviously"
echo "see a great deal of revision before +MPB's first major"
echo "release, nevertheless it's a good start."
echo ""
echo "If you wish to use the old install method, and modify"
echo "config.h, and run the building steps yourself, simply"
echo "run the OldSetup.sh script. It will prepare the files"
echo "for the old style of configuration and building Hybrid."
echo ""
echo "Preparing..."
while [ "$LOCATINGSOURCE" != "done" ]
do
  echo "Attempting to locate source files..."
  if test -f doc/mpb.txt
  then
    SHOWPWD=`pwd`
    echo "Setup has detected setup files in $SHOWPWD"
    echo "Setup will install from this directory."
    echo ""
    INSTALLSOURCE=$SHOWPWD
    LOCATINGSOURCE="done"
  else
    while [ "$ASKINGSOURCE" != "done" ]
    do
      echo "Setup was unable to locate the Hybrid7+Mpb source code on this system"
      echo "please enter the directory to install from."
      echo "Example: $HOME/ircd-hybrid-7rc6+mpb-ri"
      read INSTALLSOURCEINPUT
      if test -f $INSTALLSOURCEINPUT/doc/mpb.txt
      then
        echo "Source has been located in the directory specified:"
        echo "$INSTALLSOURCEINPUT, installing from there."
        echo ""
        INSTALLSOURCE=$INSTALLSOURCEINPUT
        cd $INSTALLSOURCE
        LOCATINGSOURCE="done"
        ASKINGSOURCE="done"
      else
        echo "The source code was not located in the directory specified."
        echo ""
      fi
    done
  fi
done
echo "Cleaning up..."
if test -f include/config.h
then
  echo "Setup has detected the existance of config.h, removing."
  rm -f include/config.h
fi
if test -f Makefile
then
  echo "Setup has detected the existance of Makefile, removing."
  rm -f Makefile
fi
if test -f src/Makefile
then
  echo "Setup has detected the existance of src/Makefile, removing."
  rm -f src/Makefile
fi
if test -f tools/Makefile
then
  echo "Setup has detected the existance of tools/Makefile, removing."
  rm -f tools/Makefile
fi
if test -f servlink/Makefile
then
  echo "Setup has detected the existance of servlink/Makefile, removing."
  rm -f servlink/Makefile
fi
if test -f modules/Makefile
then
  echo "Setup has detected the existance of modules/Makefile, removing."
  rm -f modules/Makefile
fi
if test -f messages/Makefile
then
  echo "Setup has detected the existance of messages/Makefile, removing."
  rm -f messages/Makefile
fi
if test -f include/Makefile
then
  echo "Setup has detected the existance of include/Makefile, removing."
  rm -f include/Makefile
fi
if test -f iauth/Makefile
then
  echo "Setup has detected the existance of iauth/Makefile, removing."
  rm -f iauth/Makefile
fi
if test -f iauth/source/Makefile
then
  echo "Setup has detected the existance of iauth/source/Makefile, removing."
  rm -f iauth/source/Makefile
fi
if test -f help/Makefile
then
  echo "Setup has detected the existance of help/Makefile, removing."
  rm -f help/Makefile
fi
if test -f doc/Makefile
then
  echo "Setup has detected the existance of doc/Makefile, removing."
  rm -f doc/Makefile
fi
if test -f contrib/Makefile
then
  echo "Setup has detected the existance of contrib/Makefile, removing."
  rm -f contrib/Makefile
fi
if test -f adns/Makefile
then
  echo "Setup has detected the existance of adns/Makefile, removing."
  rm -f adns/Makefile
fi
echo ""
echo "Compile time configuration setup started."
echo ""
while [ "$HYBRIDPATHSET" != "yes" ]
do
  while [ "$HYBRIDPATHVALID" != "yes" ]
  do
    echo "Please enter the path to install Hybrid7+mpb to:"
    echo "Be warned, at the current time this program does not"
    echo "check the validity of the requested path, so take"
    echo "extra care when setting this variable."
    echo "Default: /usr/local/ircd"
    read HYBRIDPATH
    if [ "$HYBRIDPATH" = "" ]
    then
      echo "No path specified, defaulting to /usr/local/ircd"
      HYBRIDPATH="/usr/local/ircd"
    fi
    echo ""
    echo "You have selected $HYBRIDPATH as your installation target, is this correct? y or n:"
    read HYBRIDPATHCONFIRM
    case $HYBRIDPATHCONFIRM in
      y) echo "Will install to $HYBRIDPATH";
         HYBRIDPATHSET="yes";
         HYBRIDPATHVALID="yes";;
      Y) echo "Will install to $HYBRIDPATH";
         HYBRIDPATHSET="yes";
         HYBRIDPATHVALID="yes";;
      yes) echo "Will install to $HYBRIDPATH";
           HYBRIDPATHSET="yes";
           HYBRIDPATHVALID="yes";;
      Yes) echo "Will install to $HYBRIDPATH";
           HYBRIDPATHSET="yes";
           HYBRIDPATHVALID="yes";;
      YES) echo "Will install to $HYBRIDPATH";
           HYBRIDPATHSET="yes";
           HYBRIDPATHVALID="yes";;
      n) echo "";;
      N) echo "";;
      no) echo "";;
      No) echo "";;
      NO) echo "";;
      *) echo "Invalid Selection: Please enter y to confirm, or n to decline.";
         echo "";;   
    esac
  done
done

while [ "$MAXIMUMCLIENTSSET" != "yes" ]
do
  while [ "$MAXIMUMCLIENTSVALID" != "yes" ]
  do
    echo ""
    echo "Please enter the maximum number of concurrent connections this server should support:"
    read MAXIMUMCLIENTS
    echo $MAXIMUMCLIENTS | grep -v [0-9] > /dev/null 2>&1
    if [ "$?" -eq "0" ]; then
      echo "Invalid answer, MAXCLIENTS requires you to use a numeric response."
    else
      echo "You have elected to support up to $MAXIMUMCLIENTS clients, is this correct? y or n:"
      read MAXIMUMCLIENTSCONFIRM
      case $MAXIMUMCLIENTSCONFIRM in
        y) echo "Will compile for $MAXIMUMCLIENTS clients."; 
           MAXIMUMCLIENTSSET="yes";
           MAXIMUMCLIENTSVALID="yes";;
        Y) echo "Will compile for $MAXIMUMCLIENTS clients.";
           MAXIMUMCLIENTSSET="yes";
           MAXIMUMCLIENTSVALID="yes";;
        yes) echo "Will compile for $MAXIMUMCLIENTS clients.";
             MAXIMUMCLIENTSSET="yes";
             MAXIMUMCLIENTSVALID="yes";;
        Yes) echo "Will compile for $MAXIMUMCLIENTS clients.";
             MAXIMUMCLIENTSSET="yes";
             MAXIMUMCLIENTSVALID="yes";;
        YES) echo "Will compile for $MAXIMUMCLIENTS clients.";
             MAXIMUMCLIENTSSET="yes";
             MAXIMUMCLIENTSVALID="yes";;
        n) echo "";;
        N) echo "";;
        no) echo "";;
        No) echo "";;
        NO) echo "";;
        *) echo "Invalid Selection: Please enter y to confirm, or n to decline.";
           echo "";;
      esac
    fi
  done
done
echo ""
echo "Hybrid7 Configuratoin Section"
while [ "$WANT_GETTEXTSET" != "yes" ]
do
  echo ""
  echo "Enable WANT_GETTEXT?"
  echo "Toggle gettext support. NOTE: if configure"
  echo "doesn't detect gettext, this won't do anything."
  echo "Default: Enabled"
  read WANT_GETTEXTCONFIRM
  if [ "$WANT_GETTEXTCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    WANT_GETTEXTCONFIRM="yes"
  fi
  case $WANT_GETTEXTCONFIRM in
    y) echo "WANT_GETTEXT will be enabled.";
       WANT_GETTEXTENABLE="Enabled";
       WANT_GETTEXTSET="yes";;
    Y) echo "WANT_GETTEXT will be enabled.";
       WANT_GETTEXTENABLE="Enabled";
       WANT_GETTEXTSET="yes";;
    yes) echo "WANT_GETTEXT will be enabled.";
       WANT_GETTEXTENABLE="Enabled";
       WANT_GETTEXTSET="yes";;
    Yes) echo "WANT_GETTEXT will be enabled.";
       WANT_GETTEXTENABLE="Enabled";
       WANT_GETTEXTSET="yes";;
    YES) echo "WANT_GETTEXT will be enabled.";
       WANT_GETTEXTENABLE="Enabled";
       WANT_GETTEXTSET="yes";;
    n) echo "WANT_GETTEXT will be disabled.";
       WANT_GETTEXTENABLE="Disabled";
       WANT_GETTEXTSET="yes";;
    N) echo "WANT_GETTEXT will be disabled.";
       WANT_GETTEXTENABLE="Disabled";
       WANT_GETTEXTSET="yes";;
    no) echo "WANT_GETTEXT will be disabled.";
       WANT_GETTEXTENABLE="Disabled";
       WANT_GETTEXTSET="yes";;
    No) echo "WANT_GETTEXT will be disabled.";
       WANT_GETTEXTENABLE="Disabled";
       WANT_GETTEXTSET="yes";;
    NO) echo "WANT_GETTEXT will be disabled.";
       WANT_GETTEXTENABLE="Disabled";
       WANT_GETTEXTSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$IGNORE_BOGUS_TSSET" != "yes" ]
do
  echo ""
  echo "Enable IGNORE_BOGUS_TS?"
  echo "Ignore bogus timestamps from other servers."
  echo "Yes this will desync the network, but it will"
  echo "allow chanops to resync with a valid non TS 0"
  echo "This should be enabled network wide,"
  echo "or not at all.  Default: Disabled"
  read IGNORE_BOGUS_TSCONFIRM
  if [ "$IGNORE_BOGUS_TSCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Disabled"
    IGNORE_BOGUS_TSCONFIRM="no"
  fi
  case $IGNORE_BOGUS_TSCONFIRM in
    y) echo "IGNORE_BOGUS_TS will be enabled.";
       IGNORE_BOGUS_TSENABLE="Enabled";
       IGNORE_BOGUS_TSSET="yes";;
    Y) echo "IGNORE_BOGUS_TS will be enabled.";
       IGNORE_BOGUS_TSENABLE="Enabled";
       IGNORE_BOGUS_TSSET="yes";;
    yes) echo "IGNORE_BOGUS_TS will be enabled.";
       IGNORE_BOGUS_TSENABLE="Enabled";
       IGNORE_BOGUS_TSSET="yes";;
    Yes) echo "IGNORE_BOGUS_TS will be enabled.";
       IGNORE_BOGUS_TSENABLE="Enabled";
       IGNORE_BOGUS_TSSET="yes";;
    YES) echo "IGNORE_BOGUS_TS will be enabled.";
       IGNORE_BOGUS_TSENABLE="Enabled";
       IGNORE_BOGUS_TSSET="yes";;
    n) echo "IGNORE_BOGUS_TS will be disabled.";
       IGNORE_BOGUS_TSENABLE="Disabled";
       IGNORE_BOGUS_TSSET="yes";;
    N) echo "IGNORE_BOGUS_TS will be disabled.";
       IGNORE_BOGUS_TSENABLE="Disabled";
       IGNORE_BOGUS_TSSET="yes";;
    no) echo "IGNORE_BOGUS_TS will be disabled.";
       IGNORE_BOGUS_TSENABLE="Disabled";
       IGNORE_BOGUS_TSSET="yes";;
    No) echo "IGNORE_BOGUS_TS will be disabled.";
       IGNORE_BOGUS_TSENABLE="Disabled";
       IGNORE_BOGUS_TSSET="yes";;
    NO) echo "IGNORE_BOGUS_TS will be disabled.";
       IGNORE_BOGUS_TSENABLE="Disabled";
       IGNORE_BOGUS_TSSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$HIDE_SERVERS_IPSSET" != "yes" ]
do
  echo ""
  echo "Enable HIDE_SERVERS_IPS?"
  echo "If this is undefined, opers will be unable to see servers ips"
  echo "and will be shown a masked ip, admins will be shown the real ip."
  echo "If this is defined, nobody can see a servers ip.  *This is a"
  echo "kludge*, it has the side effect of hiding the ips everywhere,"
  echo "including logfiles. We recommend you leave this undefined, and just"
  echo "take care with who you give admin=yes; to."
  echo "Default: Disabled"
  read HIDE_SERVERS_IPSCONFIRM
  if [ "$HIDE_SERVERS_IPSCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Disabled"
    HIDE_SERVERS_IPSCONFIRM="no"
  fi
  case $HIDE_SERVERS_IPSCONFIRM in
    y) echo "HIDE_SERVERS_IPS will be enabled.";
       HIDE_SERVERS_IPSENABLE="Enabled";
       HIDE_SERVERS_IPSSET="yes";;
    Y) echo "HIDE_SERVERS_IPS will be enabled.";
       HIDE_SERVERS_IPSENABLE="Enabled";
       HIDE_SERVERS_IPSSET="yes";;
    yes) echo "HIDE_SERVERS_IPS will be enabled.";
       HIDE_SERVERS_IPSENABLE="Enabled";
       HIDE_SERVERS_IPSSET="yes";;
    Yes) echo "HIDE_SERVERS_IPS will be enabled.";
       HIDE_SERVERS_IPSENABLE="Enabled";
       HIDE_SERVERS_IPSSET="yes";;
    YES) echo "HIDE_SERVERS_IPS will be enabled.";
       HIDE_SERVERS_IPSENABLE="Enabled";
       HIDE_SERVERS_IPSSET="yes";;
    n) echo "HIDE_SERVERS_IPS will be disabled.";
       HIDE_SERVERS_IPSENABLE="Disabled";
       HIDE_SERVERS_IPSSET="yes";;
    N) echo "HIDE_SERVERS_IPS will be disabled.";
       HIDE_SERVERS_IPSENABLE="Disabled";
       HIDE_SERVERS_IPSSET="yes";;
    no) echo "HIDE_SERVERS_IPS will be disabled.";
       HIDE_SERVERS_IPSENABLE="Disabled";
       HIDE_SERVERS_IPSSET="yes";;
    No) echo "HIDE_SERVERS_IPS will be disabled.";
       HIDE_SERVERS_IPSENABLE="Disabled";
       HIDE_SERVERS_IPSSET="yes";;
    NO) echo "HIDE_SERVERS_IPS will be disabled.";
       HIDE_SERVERS_IPSENABLE="Disabled";
       HIDE_SERVERS_IPSSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$HIDE_SPOOF_IPSSET" != "yes" ]
do
  echo ""
  echo "Enable HIDE_SPOOF_IPS?"
  echo "If this is undefined, opers will be allowed to see"
  echo "the real IP of spoofed users in /trace etc.  If this"
  echo "is defined they will be shown a masked IP."
  echo "Default: Disabled"
  read HIDE_SPOOF_IPSCONFIRM
  if [ "$HIDE_SPOOF_IPSCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Disabled"
    HIDE_SPOOF_IPSCONFIRM="no"
  fi
  case $HIDE_SPOOF_IPSCONFIRM in
    y) echo "HIDE_SPOOF_IPS will be enabled.";
       HIDE_SPOOF_IPSENABLE="Enabled";
       HIDE_SPOOF_IPSSET="yes";;
    Y) echo "HIDE_SPOOF_IPS will be enabled.";
       HIDE_SPOOF_IPSENABLE="Enabled";
       HIDE_SPOOF_IPSSET="yes";;
    yes) echo "HIDE_SPOOF_IPS will be enabled.";
       HIDE_SPOOF_IPSENABLE="Enabled";
       HIDE_SPOOF_IPSSET="yes";;
    Yes) echo "HIDE_SPOOF_IPS will be enabled.";
       HIDE_SPOOF_IPSENABLE="Enabled";
       HIDE_SPOOF_IPSSET="yes";;
    YES) echo "HIDE_SPOOF_IPS will be enabled.";
       HIDE_SPOOF_IPSENABLE="Enabled";
       HIDE_SPOOF_IPSSET="yes";;
    n) echo "HIDE_SPOOF_IPS will be disabled.";
       HIDE_SPOOF_IPSENABLE="Disabled";
       HIDE_SPOOF_IPSSET="yes";;
    N) echo "HIDE_SPOOF_IPS will be disabled.";
       HIDE_SPOOF_IPSENABLE="Disabled";
       HIDE_SPOOF_IPSSET="yes";;
    no) echo "HIDE_SPOOF_IPS will be disabled.";
       HIDE_SPOOF_IPSENABLE="Disabled";
       HIDE_SPOOF_IPSSET="yes";;
    No) echo "HIDE_SPOOF_IPS will be disabled.";
       HIDE_SPOOF_IPSENABLE="Disabled";
       HIDE_SPOOF_IPSSET="yes";;
    NO) echo "HIDE_SPOOF_IPS will be disabled.";
       HIDE_SPOOF_IPSENABLE="Disabled";
       HIDE_SPOOF_IPSSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$TS5_ONLYSET" != "yes" ]
do
  echo ""
  echo "Enable TS5_ONLY?"
  echo "If this is defined only TS5 servers may link to the"
  echo "network.  See doc/ts5.txt for more information.  If"
  echo "your network has old servers (hyb5, hyb6.0, +CSr) or"
  echo "hybserv you should NOT define this."
  echo "Default: Disabled"
  read TS5_ONLYCONFIRM
  if [ "$TS5_ONLYCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Disabled"
    TS5_ONLYCONFIRM="no"
  fi
  case $TS5_ONLYCONFIRM in
    y) echo "TS5_ONLY will be enabled.";
       TS5_ONLYENABLE="Enabled";
       TS5_ONLYSET="yes";;
    Y) echo "TS5_ONLY will be enabled.";
       TS5_ONLYENABLE="Enabled";
       TS5_ONLYSET="yes";;
    yes) echo "TS5_ONLY will be enabled.";
       TS5_ONLYENABLE="Enabled";
       TS5_ONLYSET="yes";;
    Yes) echo "TS5_ONLY will be enabled.";
       TS5_ONLYENABLE="Enabled";
       TS5_ONLYSET="yes";;
    YES) echo "TS5_ONLY will be enabled.";
       TS5_ONLYENABLE="Enabled";
       TS5_ONLYSET="yes";;
    n) echo "TS5_ONLY will be disabled.";
       TS5_ONLYENABLE="Disabled";
       TS5_ONLYSET="yes";;
    N) echo "TS5_ONLY will be disabled.";
       TS5_ONLYENABLE="Disabled";
       TS5_ONLYSET="yes";;
    no) echo "TS5_ONLY will be disabled.";
       TS5_ONLYENABLE="Disabled";
       TS5_ONLYSET="yes";;
    No) echo "TS5_ONLY will be disabled.";
       TS5_ONLYENABLE="Disabled";
       TS5_ONLYSET="yes";;
    NO) echo "TS5_ONLY will be disabled.";
       TS5_ONLYENABLE="Disabled";
       TS5_ONLYSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$USE_LOGFILESET" != "yes" ]
do
  echo ""
  echo "Enable USE_LOGFILE?"
  echo "log errors and such to syslog() If you wish to have"
  echo "the server send 'vital' messages about server through"
  echo "syslog, define USE_SYSLOG. Only system errors and events" 
  echo "critical to the server are logged although if this is"
  echo "defined with FNAME_USERLOG, syslog() is used instead of"
  echo "the above file. It is not recommended that this option is" 
  echo "used unless you tell the system administrator beforehand"
  echo "and obtain their permission to send messages to the"
  echo "system log files.  Default: Enabled"
  read USE_LOGFILECONFIRM
  if [ "$USE_LOGFILECONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    USE_LOGFILECONFIRM="yes"
  fi
  case $USE_LOGFILECONFIRM in
    y) echo "USE_LOGFILE will be enabled.";
       USE_LOGFILEENABLE="Enabled";
       USE_LOGFILESET="yes";;
    Y) echo "USE_LOGFILE will be enabled.";
       USE_LOGFILEENABLE="Enabled";
       USE_LOGFILESET="yes";;
    yes) echo "USE_LOGFILE will be enabled.";
       USE_LOGFILEENABLE="Enabled";
       USE_LOGFILESET="yes";;
    Yes) echo "USE_LOGFILE will be enabled.";
       USE_LOGFILEENABLE="Enabled";
       USE_LOGFILESET="yes";;
    YES) echo "USE_LOGFILE will be enabled.";
       USE_LOGFILEENABLE="Enabled";
       USE_LOGFILESET="yes";;
    n) echo "USE_LOGFILE will be disabled.";
       USE_LOGFILEENABLE="Disabled";
       USE_LOGFILESET="yes";;
    N) echo "USE_LOGFILE will be disabled.";
       USE_LOGFILEENABLE="Disabled";
       USE_LOGFILESET="yes";;
    no) echo "USE_LOGFILE will be disabled.";
       USE_LOGFILEENABLE="Disabled";
       USE_LOGFILESET="yes";;
    No) echo "USE_LOGFILE will be disabled.";
       USE_LOGFILEENABLE="Disabled";
       USE_LOGFILESET="yes";;
    NO) echo "USE_LOGFILE will be disabled.";
       USE_LOGFILEENABLE="Disabled";
       USE_LOGFILESET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$USE_SYSLOGSET" != "yes" ]
do
  echo ""
  echo "Enable USE_SYSLOG?"
  echo "log errors and such to syslog() If you wish to have"
  echo "the server send 'vital' messages about server through"
  echo "syslog, define USE_SYSLOG. Only system errors and events"
  echo "critical to the server are logged although if this is"
  echo "defined with FNAME_USERLOG, syslog() is used instead of"
  echo "the above file. It is not recommended that this option is" 
  echo "used unless you tell the system administrator beforehand"
  echo "and obtain their permission to send messages to the system"
  echo "log files.  Default: Disabled."
  read USE_SYSLOGCONFIRM
  if [ "$USE_SYSLOGCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Disabled"
    USE_SYSLOGCONFIRM="no"
  fi
  case $USE_SYSLOGCONFIRM in
    y) echo "USE_SYSLOG will be enabled.";
       USE_SYSLOGENABLE="Enabled";
       USE_SYSLOGSET="yes";;
    Y) echo "USE_SYSLOG will be enabled.";
       USE_SYSLOGENABLE="Enabled";
       USE_SYSLOGSET="yes";;
    yes) echo "USE_SYSLOG will be enabled.";
       USE_SYSLOGENABLE="Enabled";
       USE_SYSLOGSET="yes";;
    Yes) echo "USE_SYSLOG will be enabled.";
       USE_SYSLOGENABLE="Enabled";
       USE_SYSLOGSET="yes";;
    YES) echo "USE_SYSLOG will be enabled.";
       USE_SYSLOGENABLE="Enabled";
       USE_SYSLOGSET="yes";;
    n) echo "USE_SYSLOG will be disabled.";
       USE_SYSLOGENABLE="Disabled";
       USE_SYSLOGSET="yes";;
    N) echo "USE_SYSLOG will be disabled.";
       USE_SYSLOGENABLE="Disabled";
       USE_SYSLOGSET="yes";;
    no) echo "USE_SYSLOG will be disabled.";
       USE_SYSLOGENABLE="Disabled";
       USE_SYSLOGSET="yes";;
    No) echo "USE_SYSLOG will be disabled.";
       USE_SYSLOGENABLE="Disabled";
       USE_SYSLOGSET="yes";;
    NO) echo "USE_SYSLOG will be disabled.";
       USE_SYSLOGENABLE="Disabled";
       USE_SYSLOGSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
if [ "$USE_SYSLOGENABLE" = "Enabled" ]
then
  while [ "$SYSLOG_KILLSET" != "yes" ]
  do
    echo ""
    echo "Enable SYSLOG_KILL?"
    echo "Log all operator kills to syslog."
    echo "Default: Disabled"
    read SYSLOG_KILLCONFIRM
    if [ "$SYSLOG_KILLCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Disabled"
      SYSLOG_KILLCONFIRM="no"
    fi
    case $SYSLOG_KILLCONFIRM in
      y) echo "SYSLOG_KILL will be enabled.";
         SYSLOG_KILLENABLE="Enabled";
         SYSLOG_KILLSET="yes";;
      Y) echo "SYSLOG_KILL will be enabled.";
         SYSLOG_KILLENABLE="Enabled";
         SYSLOG_KILLSET="yes";;
      yes) echo "SYSLOG_KILL will be enabled.";
         SYSLOG_KILLENABLE="Enabled";
         SYSLOG_KILLSET="yes";;
      Yes) echo "SYSLOG_KILL will be enabled.";
         SYSLOG_KILLENABLE="Enabled";
         SYSLOG_KILLSET="yes";;
      YES) echo "SYSLOG_KILL will be enabled.";
         SYSLOG_KILLENABLE="Enabled";
         SYSLOG_KILLSET="yes";;
      n) echo "SYSLOG_KILL will be disabled.";
         SYSLOG_KILLENABLE="Disabled";
         SYSLOG_KILLSET="yes";;
      N) echo "SYSLOG_KILL will be disabled.";
         SYSLOG_KILLENABLE="Disabled";
         SYSLOG_KILLSET="yes";;
      no) echo "SYSLOG_KILL will be disabled.";
         SYSLOG_KILLENABLE="Disabled";
         SYSLOG_KILLSET="yes";;
      No) echo "SYSLOG_KILL will be disabled.";
         SYSLOG_KILLENABLE="Disabled";
         SYSLOG_KILLSET="yes";;
      NO) echo "SYSLOG_KILL will be disabled.";
         SYSLOG_KILLENABLE="Disabled";
         SYSLOG_KILLSET="yes";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
  while [ "$SYSLOG_SQUITSET" != "yes" ]
  do
    echo ""
    echo "Enable SYSLOG_SQUIT?"
    echo "Log all remote squits for all servers to syslog."
    echo "Default: Disabled"
    read SYSLOG_SQUITCONFIRM
    if [ "$SYSLOG_SQUITCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Disabled"
      SYSLOG_SQUITCONFIRM="no"
    fi
    case $SYSLOG_SQUITCONFIRM in
      y) echo "SYSLOG_SQUIT will be enabled.";
         SYSLOG_SQUITENABLE="Enabled";
         SYSLOG_SQUITSET="yes";;
      Y) echo "SYSLOG_SQUIT will be enabled.";
         SYSLOG_SQUITENABLE="Enabled";
         SYSLOG_SQUITSET="yes";;
      yes) echo "SYSLOG_SQUIT will be enabled.";
         SYSLOG_SQUITENABLE="Enabled";
         SYSLOG_SQUITSET="yes";;
      Yes) echo "SYSLOG_SQUIT will be enabled.";
         SYSLOG_SQUITENABLE="Enabled";
         SYSLOG_SQUITSET="yes";;
      YES) echo "SYSLOG_SQUIT will be enabled.";
         SYSLOG_SQUITENABLE="Enabled";
         SYSLOG_SQUITSET="yes";;
      n) echo "SYSLOG_SQUIT will be disabled.";
         SYSLOG_SQUITENABLE="Disabled";
         SYSLOG_SQUITSET="yes";;
      N) echo "SYSLOG_SQUIT will be disabled.";
         SYSLOG_SQUITENABLE="Disabled";
         SYSLOG_SQUITSET="yes";;
      no) echo "SYSLOG_SQUIT will be disabled.";
         SYSLOG_SQUITENABLE="Disabled";
         SYSLOG_SQUITSET="yes";;
      No) echo "SYSLOG_SQUIT will be disabled.";
         SYSLOG_SQUITENABLE="Disabled";
         SYSLOG_SQUITSET="yes";;
      NO) echo "SYSLOG_SQUIT will be disabled.";
         SYSLOG_SQUITENABLE="Disabled";
         SYSLOG_SQUITSET="yes";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
  while [ "$SYSLOG_CONNECTSET" != "yes" ]
  do
    echo ""
    echo "Enable SYSLOG_CONNECT?"
    echo "Log remote connect messages for other all servs"
    echo "Default: Disabled"
    read SYSLOG_CONNECTCONFIRM
    if [ "$SYSLOG_CONNECTCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Disabled"
      SYSLOG_CONNECTCONFIRM="no"
    fi
    case $SYSLOG_CONNECTCONFIRM in
      y) echo "SYSLOG_CONNECT will be enabled.";
         SYSLOG_CONNECTENABLE="Enabled";
         SYSLOG_CONNECTSET="yes";;
      Y) echo "SYSLOG_CONNECT will be enabled.";
         SYSLOG_CONNECTENABLE="Enabled";
         SYSLOG_CONNECTSET="yes";;
      yes) echo "SYSLOG_CONNECT will be enabled.";
         SYSLOG_CONNECTENABLE="Enabled";
         SYSLOG_CONNECTSET="yes";;
      Yes) echo "SYSLOG_CONNECT will be enabled.";
         SYSLOG_CONNECTENABLE="Enabled";
         SYSLOG_CONNECTSET="yes";;
      YES) echo "SYSLOG_CONNECT will be enabled.";
         SYSLOG_CONNECTENABLE="Enabled";
         SYSLOG_CONNECTSET="yes";;
      n) echo "SYSLOG_CONNECT will be disabled.";
         SYSLOG_CONNECTENABLE="Disabled";
         SYSLOG_CONNECTSET="yes";;
      N) echo "SYSLOG_CONNECT will be disabled.";
         SYSLOG_CONNECTENABLE="Disabled";
         SYSLOG_CONNECTSET="yes";;
      no) echo "SYSLOG_CONNECT will be disabled.";
         SYSLOG_CONNECTENABLE="Disabled";
         SYSLOG_CONNECTSET="yes";;
      No) echo "SYSLOG_CONNECT will be disabled.";
         SYSLOG_CONNECTENABLE="Disabled";
         SYSLOG_CONNECTSET="yes";;
      NO) echo "SYSLOG_CONNECT will be disabled.";
         SYSLOG_CONNECTENABLE="Disabled";
         SYSLOG_CONNECTSET="yes";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
  while [ "$SYSLOG_USERSSET" != "yes" ]
  do
    echo ""
    echo "Enable SYSLOG_USERS?"
    echo "Send userlog stuff to syslog"
    echo "Default: Disabled"
    read SYSLOG_USERSCONFIRM
    if [ "$SYSLOG_USERSCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Disabled"
      SYSLOG_USERSCONFIRM="no"
    fi
    case $SYSLOG_USERSCONFIRM in
      y) echo "SYSLOG_USERS will be enabled.";
         SYSLOG_USERSENABLE="Enabled";
         SYSLOG_USERSSET="yes";;
      Y) echo "SYSLOG_USERS will be enabled.";
         SYSLOG_USERSENABLE="Enabled";
         SYSLOG_USERSSET="yes";;
      yes) echo "SYSLOG_USERS will be enabled.";
         SYSLOG_USERSENABLE="Enabled";
         SYSLOG_USERSSET="yes";;
      Yes) echo "SYSLOG_USERS will be enabled.";
         SYSLOG_USERSENABLE="Enabled";
         SYSLOG_USERSSET="yes";;
      YES) echo "SYSLOG_USERS will be enabled.";
         SYSLOG_USERSENABLE="Enabled";
         SYSLOG_USERSSET="yes";;
      n) echo "SYSLOG_USERS will be disabled.";
         SYSLOG_USERSENABLE="Disabled";
         SYSLOG_USERSSET="yes";;
      N) echo "SYSLOG_USERS will be disabled.";
         SYSLOG_USERSENABLE="Disabled";
         SYSLOG_USERSSET="yes";;
      no) echo "SYSLOG_USERS will be disabled.";
         SYSLOG_USERSENABLE="Disabled";
         SYSLOG_USERSSET="yes";;
      No) echo "SYSLOG_USERS will be disabled.";
         SYSLOG_USERSENABLE="Disabled";
         SYSLOG_USERSSET="yes";;
      NO) echo "SYSLOG_USERS will be disabled.";
         SYSLOG_USERSENABLE="Disabled";
         SYSLOG_USERSSET="yes";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
  while [ "$SYSLOG_OPERSET" != "yes" ]
  do
    echo ""
    echo "Enable SYSLOG_OPER?"
    echo "Log all users who successfully become an Op"
    echo "Default: Disabled"
    read SYSLOG_OPERCONFIRM
    if [ "$SYSLOG_OPERCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Disabled"
      SYSLOG_OPERCONFIRM="no"
    fi
    case $SYSLOG_OPERCONFIRM in
      y) echo "SYSLOG_OPER will be enabled.";
         SYSLOG_OPERENABLE="Enabled";
         SYSLOG_OPERSET="yes";;
      Y) echo "SYSLOG_OPER will be enabled.";
         SYSLOG_OPERENABLE="Enabled";
         SYSLOG_OPERSET="yes";;
      yes) echo "SYSLOG_OPER will be enabled.";
         SYSLOG_OPERENABLE="Enabled";
         SYSLOG_OPERSET="yes";;
      Yes) echo "SYSLOG_OPER will be enabled.";
         SYSLOG_OPERENABLE="Enabled";
         SYSLOG_OPERSET="yes";;
      YES) echo "SYSLOG_OPER will be enabled.";
         SYSLOG_OPERENABLE="Enabled";
         SYSLOG_OPERSET="yes";;
      n) echo "SYSLOG_OPER will be disabled.";
         SYSLOG_OPERENABLE="Disabled";
         SYSLOG_OPERSET="yes";;
      N) echo "SYSLOG_OPER will be disabled.";
         SYSLOG_OPERENABLE="Disabled";
         SYSLOG_OPERSET="yes";;
      no) echo "SYSLOG_OPER will be disabled.";
         SYSLOG_OPERENABLE="Disabled";
         SYSLOG_OPERSET="yes";;
      No) echo "SYSLOG_OPER will be disabled.";
         SYSLOG_OPERENABLE="Disabled";
         SYSLOG_OPERSET="yes";;
      NO) echo "SYSLOG_OPER will be disabled.";
         SYSLOG_OPERENABLE="Disabled";
         SYSLOG_OPERSET="yes";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
  while [ "$LOG_FACILITYSET" != "yes" ]
  do
    echo ""
    echo "Set LOG_FACILITY"
    echo "facility to use for syslog()  Define the facility"
    echo "you want to use for syslog().  Ask your sysadmin"
    echo "which one you should use."
    echo "Default: LOG_LOCAL4"
    read LOG_FACILITYINPUT
    if [ "$LOG_FACILITYINPUT" = "" ]; then
      echo "None specified, using default of: LOG_LOCAL4"
      LOG_FACILITYINPUT="LOG_LOCAL4"
    fi
    echo "You have selected $LOG_FACILITYINPUT as your LOG_FACILITY, is this correct?"
    read LOG_FACILITYCONFIRM
    case $LOG_FACILITYCONFIRM in
      y) echo "LOG_FACILITY $LOG_FACILITYINPUT will be used.";
         LOG_FACILITYSETTING="$LOG_FACILITYINPUT";
         LOG_FACILITYSET="yes";;
      Y) echo "LOG_FACILITY $LOG_FACILITYINPUT will be used.";
         LOG_FACILITYSETTING="$LOG_FACILITYINPUT";
         LOG_FACILITYSET="yes";;
      yes) echo "LOG_FACILITY $LOG_FACILITYINPUT will be used.";
         LOG_FACILITYSETTING="$LOG_FACILITYINPUT";
         LOG_FACILITYSET="yes";;
      Yes) echo "LOG_FACILITY $LOG_FACILITYINPUT will be used.";
         LOG_FACILITYSETTING="$LOG_FACILITYINPUT";
         LOG_FACILITYSET="yes";;
      YES) echo "LOG_FACILITY $LOG_FACILITYINPUT will be used.";
         LOG_FACILITYSETTING="$LOG_FACILITYINPUT";
         LOG_FACILITYSET="yes";;
      n) echo "";;
      N) echo "";;
      no) echo "";;
      No) echo "";;
      NO) echo "";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
else
  SYSLOG_KILLENABLE="Disabled"
  SYSLOG_SQUITENABLE="Disabled"
  SYSLOG_CONNECTENABLE="Disabled"
  SYSLOG_USERSENABLE="Disabled"
  SYSLOG_OPERENABLE="Disabled"
  LOG_FACILITYENABLE="Disabled"
  LOG_FACILITYSETTING="LOG_LOCAL4"
fi
while [ "$CRYPT_OPER_PASSWORDSET" != "yes" ]
do
  echo ""
  echo "Enable CRYPT_OPER_PASSWORD?"
  echo "use crypted oper passwords in the ircd.conf define"
  echo "this if you want to use crypted passwords for operators"
  echo "in your ircd.conf file.  Default: Enabled"
  read CRYPT_OPER_PASSWORDCONFIRM
  if [ "$CRYPT_OPER_PASSWORDCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    CRYPT_OPER_PASSWORDCONFIRM="yes"
  fi
  case $CRYPT_OPER_PASSWORDCONFIRM in
    y) echo "CRYPT_OPER_PASSWORD will be enabled.";
       CRYPT_OPER_PASSWORDENABLE="Enabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    Y) echo "CRYPT_OPER_PASSWORD will be enabled.";
       CRYPT_OPER_PASSWORDENABLE="Enabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    yes) echo "CRYPT_OPER_PASSWORD will be enabled.";
       CRYPT_OPER_PASSWORDENABLE="Enabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    Yes) echo "CRYPT_OPER_PASSWORD will be enabled.";
       CRYPT_OPER_PASSWORDENABLE="Enabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    YES) echo "CRYPT_OPER_PASSWORD will be enabled.";
       CRYPT_OPER_PASSWORDENABLE="Enabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    n) echo "CRYPT_OPER_PASSWORD will be disabled.";
       CRYPT_OPER_PASSWORDENABLE="Disabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    N) echo "CRYPT_OPER_PASSWORD will be disabled.";
       CRYPT_OPER_PASSWORDENABLE="Disabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    no) echo "CRYPT_OPER_PASSWORD will be disabled.";
       CRYPT_OPER_PASSWORDENABLE="Disabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    No) echo "CRYPT_OPER_PASSWORD will be disabled.";
       CRYPT_OPER_PASSWORDENABLE="Disabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    NO) echo "CRYPT_OPER_PASSWORD will be disabled.";
       CRYPT_OPER_PASSWORDENABLE="Disabled";
       CRYPT_OPER_PASSWORDSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$CLIENT_FLOODSET" != "yes" ]
do
  echo ""
  echo "Set CLIENT_FLOOD"
  echo "client excess flood threshold(in messages) The number"
  echo "of messages that we can receive before we disconnect"
  echo "the remote client...  Default: 20"
  read CLIENT_FLOODINPUT
  if [ "$CLIENT_FLOODINPUT" = "" ]; then
    echo "No option specified, setting default of: 20"
    CLIENT_FLOODINPUT="20"
  fi
  echo $CLIENT_FLOODINPUT | grep -v [0-9] > /dev/null 2>&1
  if [ "$?" -eq "0" ]; then
    echo "Value for CLIENT_FLOOD is restricted to only numeric characters."
  else
    echo "You have elected to set CLIENT_FLOOD to $CLIENT_FLOODINPUT, is this correct?"
    read CLIENT_FLOODCONFIRM
    case $CLIENT_FLOODCONFIRM in
      y) echo "CLIENT_FLOOD will be set to $CLIENT_FLOODCONFIRM";
         CLIENT_FLOODSETTING="$CLIENT_FLOODINPUT";
         CLIENT_FLOODSET="yes";;
      Y) echo "CLIENT_FLOOD will be set to $CLIENT_FLOODCONFIRM";
         CLIENT_FLOODSETTING="$CLIENT_FLOODINPUT";
         CLIENT_FLOODSET="yes";;
      yes) echo "CLIENT_FLOOD will be set to $CLIENT_FLOODCONFIRM";
         CLIENT_FLOODSETTING="$CLIENT_FLOODINPUT";
         CLIENT_FLOODSET="yes";;
      Yes) echo "CLIENT_FLOOD will be set to $CLIENT_FLOODCONFIRM";
         CLIENT_FLOODSETTING="$CLIENT_FLOODINPUT";
         CLIENT_FLOODSET="yes";;
      YES) echo "CLIENT_FLOOD will be set to $CLIENT_FLOODCONFIRM";
         CLIENT_FLOODSETTING="$CLIENT_FLOODINPUT";
         CLIENT_FLOODSET="yes";;
      n) echo "";;
      N) echo "";;
      no) echo "";;
      No) echo "";;
      NO) echo "";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  fi
done
echo ""
echo "+MPB Modifications Configuration Section"
while [ "$ADMINOWNAGESET" != "yes" ]
do
  echo ""
  echo "Enable ADMINOWNAGE?"
  echo "Allows Administrators to join channels past channel"
  echo "modes such as bans, limits, invite only and keys."
  echo "Added by Michael P. Bramel for hybrid7+mpb"
  echo "Default: Enabled"
  read ADMINOWNAGECONFIRM
  if [ "$ADMINOWNAGECONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    ADMINOWNAGECONFIRM="yes"
  fi
  case $ADMINOWNAGECONFIRM in
    y) echo "ADMINOWNAGE will be enabled.";
       ADMINOWNAGEENABLE="Enabled";
       ADMINOWNAGESET="yes";;
    Y) echo "ADMINOWNAGE will be enabled.";
       ADMINOWNAGEENABLE="Enabled";            
       ADMINOWNAGESET="yes";;
    yes) echo "ADMINOWNAGE will be enabled.";
       ADMINOWNAGEENABLE="Enabled";            
       ADMINOWNAGESET="yes";;
    Yes) echo "ADMINOWNAGE will be enabled.";
       ADMINOWNAGEENABLE="Enabled";            
       ADMINOWNAGESET="yes";;
    YES) echo "ADMINOWNAGE will be enabled.";
       ADMINOWNAGEENABLE="Enabled";            
       ADMINOWNAGESET="yes";;
    n) echo "ADMINOWNAGE will be disabled.";
       ADMINOWNAGEENABLE="Disabled";
       ADMINOWNAGESET="yes";;
    N) echo "ADMINOWNAGE will be disabled.";
       ADMINOWNAGEENABLE="Disabled";
       ADMINOWNAGESET="yes";;
    no) echo "ADMINOWNAGE will be disabled.";
       ADMINOWNAGEENABLE="Disabled";
       ADMINOWNAGESET="yes";;
    No) echo "ADMINOWNAGE will be disabled.";
       ADMINOWNAGEENABLE="Disabled";
       ADMINOWNAGESET="yes";;
    NO) echo "ADMINOWNAGE will be disabled.";
       ADMINOWNAGEENABLE="Disabled";
       ADMINOWNAGESET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
if [ "$ADMINOWNAGEENABLE" = "Enabled" ]; then
  while [ "$REPORT_ADMINOWNAGESET" != "yes" ]
  do
    echo ""
    echo "Enable REPORT_ADMINOWNAGE?"
    echo "Reports use/abuse of ADMINOWNAGE functionality to other server"
    echo "operators. Option ADMINOWNAGE must be enabled for this to work."
    echo "Added by Michael P. Bramel for Hybrid-7+mpb"
    echo "Default: Enabled."
    read REPORT_ADMINOWNAGECONFIRM
      if [ "$REPORT_ADMINOWNAGECONFIRM" = "" ]; then
        echo "No option specified, setting default of: Enabled"
        REPORT_ADMINOWNAGECONFIRM="yes"
      fi
    case $REPORT_ADMINOWNAGECONFIRM in
      y) echo "REPORT_ADMINOWNAGE will be enabled.";
         REPORT_ADMINOWNAGEENABLE="Enabled";
         REPORT_ADMINOWNAGESET="yes";;
      Y) echo "REPORT_ADMINOWNAGE will be enabled.";
         REPORT_ADMINOWNAGEENABLE="Enabled";
         REPORT_ADMINOWNAGESET="yes";;
      yes) echo "REPORT_ADMINOWNAGE will be enabled.";
         REPORT_ADMINOWNAGEENABLE="Enabled";
         REPORT_ADMINOWNAGESET="yes";;
      Yes) echo "REPORT_ADMINOWNAGE will be enabled.";
         REPORT_ADMINOWNAGEENABLE="Enabled";
         REPORT_ADMINOWNAGESET="yes";;
      YES) echo "REPORT_ADMINOWNAGE will be enabled.";
         REPORT_ADMINOWNAGEENABLE="Enabled";
         REPORT_ADMINOWNAGESET="yes";;
      n) echo "REPORT_ADMINOWNAGE will be disabled.";
         REPORT_ADMINOWNAGEENABLE="Disabled";
         REPORT_ADMINOWNAGESET="yes";;
      N) echo "REPORT_ADMINOWNAGE will be disabled.";
         REPORT_ADMINOWNAGEENABLE="Disabled";
         REPORT_ADMINOWNAGESET="yes";;
      no) echo "REPORT_ADMINOWNAGE will be disabled.";
         REPORT_ADMINOWNAGEENABLE="Disabled";
         REPORT_ADMINOWNAGESET="yes";;
      No) echo "REPORT_ADMINOWNAGE will be disabled.";
         REPORT_ADMINOWNAGEENABLE="Disabled";
         REPORT_ADMINOWNAGESET="yes";;
      NO) echo "REPORT_ADMINOWNAGE will be disabled.";
         REPORT_ADMINOWNAGEENABLE="Disabled";
         REPORT_ADMINOWNAGESET="yes";;
      *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
    esac
  done
else
  REPORT_ADMINOWNAGEENABLE="Disabled"
fi
while [ "$CHANNELSPYSET" != "yes" ]
do
  echo ""
  echo "Enable CHANNELSPY?"
  echo "Toggles support for Administrators seeing channel join/part/kick"
  echo "info. Added by Michael P. Bramel for hybrid-7+mpb"
  echo "Default: Enabled"
  read CHANNELSPYCONFIRM
    if [ "$CHANNELSPYCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Enabled"
      CHANNELSPYCONFIRM="yes"
    fi
  case $CHANNELSPYCONFIRM in
    y) echo "CHANNELSPY will be enabled.";
       CHANNELSPYENABLE="Enabled";
       CHANNELSPYSET="yes";;
    Y) echo "CHANNELSPY will be enabled.";
       CHANNELSPYENABLE="Enabled";
       CHANNELSPYSET="yes";;
    yes) echo "CHANNELSPY will be enabled.";
       CHANNELSPYENABLE="Enabled";
       CHANNELSPYSET="yes";;
    Yes) echo "CHANNELSPY will be enabled.";
       CHANNELSPYENABLE="Enabled";
       CHANNELSPYSET="yes";;
    YES) echo "CHANNELSPY will be enabled.";
       CHANNELSPYENABLE="Enabled";
       CHANNELSPYSET="yes";;
    n) echo "CHANNELSPY will be disabled.";
       CHANNELSPYENABLE="Disabled";
       CHANNELSPYSET="yes";;
    N) echo "CHANNELSPY will be disabled.";
       CHANNELSPYENABLE="Disabled";
       CHANNELSPYSET="yes";;
    no) echo "CHANNELSPY will be disabled.";
       CHANNELSPYENABLE="Disabled";
       CHANNELSPYSET="yes";;
    No) echo "CHANNELSPY will be disabled.";
       CHANNELSPYENABLE="Disabled";
       CHANNELSPYSET="yes";;
    NO) echo "CHANNELSPY will be disabled.";
       CHANNELSPYENABLE="Disabled";
       CHANNELSPYSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$ALLOWWILDTOPLEVELSET" != "yes" ]
do
  echo ""
  echo "Enable ALLOWWILDTOPLEVEL?"
  echo "If this is enabled, Hybrid will not require top level"
  echo "domains to be specified in mass messages from IRC Operators."
  echo "Added by Michael P. Bramel for Hybrid-7+mpb"
  echo "** Will only work if enabled network-wide **"
  echo "Default: Enabled"
  read ALLOWWILDTOPLEVELCONFIRM
    if [ "$ALLOWWILDTOPLEVELCONFIRM" = "" ]; then
      echo "No option specified, setting default of: Enabled"
      ALLOWWILDTOPLEVELCONFIRM="yes"
    fi
  case $ALLOWWILDTOPLEVELCONFIRM in
    y) echo "ALLOWWILDTOPLEVEL will be enabled.";
       ALLOWWILDTOPLEVELENABLE="Enabled";
       ALLOWWILDTOPLEVELSET="yes";;
    Y) echo "ALLOWWILDTOPLEVEL will be enabled.";
       ALLOWWILDTOPLEVELENABLE="Enabled";
       ALLOWWILDTOPLEVELSET="yes";;
    yes) echo "ALLOWWILDTOPLEVEL will be enabled.";
       ALLOWWILDTOPLEVELENABLE="Enabled";
       ALLOWWILDTOPLEVELSET="yes";;
    Yes) echo "ALLOWWILDTOPLEVEL will be enabled.";
       ALLOWWILDTOPLEVELENABLE="Enabled";
       ALLOWWILDTOPLEVELSET="yes";;
    YES) echo "ALLOWWILDTOPLEVEL will be enabled.";
       ALLOWWILDTOPLEVELENABLE="Enabled";
       ALLOWWILDTOPLEVELSET="yes";;
    n) echo "ALLOWWILDTOPLEVEL will be disabled.";
       ALLOWWILDTOPLEVELENABLE="Disabled";
       ALLOWWILDTOPLEVELSET="yes";;
    N) echo "ALLOWWILDTOPLEVEL will be disabled.";  
       ALLOWWILDTOPLEVELENABLE="Disabled";
       ALLOWWILDTOPLEVELSET="yes";;
    no) echo "ALLOWWILDTOPLEVEL will be disabled.";  
       ALLOWWILDTOPLEVELENABLE="Disabled";
       ALLOWWILDTOPLEVELSET="yes";;
    No) echo "ALLOWWILDTOPLEVEL will be disabled.";  
       ALLOWWILDTOPLEVELENABLE="Disabled";
       ALLOWWILDTOPLEVELSET="yes";;
    NO) echo "ALLOWWILDTOPLEVEL will be disabled.";  
       ALLOWWILDTOPLEVELENABLE="Disabled";
       ALLOWWILDTOPLEVELSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$ADMINSSEEALLCHANSSET" != "yes" ]
do
  echo ""
  echo "Enable ADMINSSEEALLCHANS?"
  echo "Toggle support for admins seeing all chans in list and whois"
  echo "Added by Michael P. Bramel for hybrid-7+mpb"
  echo "Default: Enabled"
  read ADMINSSEEALLCHANSCONFIRM
  if [ "$ADMINSSEEALLCHANSCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    ADMINSSEEALLCHANSCONFIRM="yes"
  fi
  case $ADMINSSEEALLCHANSCONFIRM in
    y) echo "ADMINSSEEALLCHANS will be enabled.";
       ADMINSSEEALLCHANSENABLE="Enabled";
       ADMINSSEEALLCHANSSET="yes";;
    Y) echo "ADMINSSEEALLCHANS will be enabled.";
       ADMINSSEEALLCHANSENABLE="Enabled";
       ADMINSSEEALLCHANSSET="yes";;
    yes) echo "ADMINSSEEALLCHANS will be enabled.";
       ADMINSSEEALLCHANSENABLE="Enabled";
       ADMINSSEEALLCHANSSET="yes";;
    Yes) echo "ADMINSSEEALLCHANS will be enabled.";
       ADMINSSEEALLCHANSENABLE="Enabled";
       ADMINSSEEALLCHANSSET="yes";;
    YES) echo "ADMINSSEEALLCHANS will be enabled.";
       ADMINSSEEALLCHANSENABLE="Enabled";
       ADMINSSEEALLCHANSSET="yes";;
    n) echo "ADMINSSEEALLCHANS will be disabled.";
       ADMINSSEEALLCHANSENABLE="Disabled";
       ADMINSSEEALLCHANSSET="yes";;
    N) echo "ADMINSSEEALLCHANS will be disabled.";
       ADMINSSEEALLCHANSENABLE="Disabled";
       ADMINSSEEALLCHANSSET="yes";;
    no) echo "ADMINSSEEALLCHANS will be disabled.";
       ADMINSSEEALLCHANSENABLE="Disabled";
       ADMINSSEEALLCHANSSET="yes";;
    No) echo "ADMINSSEEALLCHANS will be disabled.";
       ADMINSSEEALLCHANSENABLE="Disabled";
       ADMINSSEEALLCHANSSET="yes";;
    NO) echo "ADMINSSEEALLCHANS will be disabled.";
       ADMINSSEEALLCHANSENABLE="Disabled";
       ADMINSSEEALLCHANSSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$RWHOIS_NOTICESET" != "yes" ]
do
  echo ""
  echo "Enable RWHOIS_NOTICE?"
  echo "Toggle support for seeing remote whois requests"
  echo "Added by Michael P. Bramel for hybrid-7+mpb"
  echo "Default: Enabled"
  read RWHOIS_NOTICECONFIRM
  if [ "$RWHOIS_NOTICECONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    RWHOIS_NOTICECONFIRM="yes"
  fi
  case $RWHOIS_NOTICECONFIRM in
    y) echo "RWHOIS_NOTICE will be enabled.";
       RWHOIS_NOTICEENABLE="Enabled";
       RWHOIS_NOTICESET="yes";;
    Y) echo "RWHOIS_NOTICE will be enabled.";
       RWHOIS_NOTICEENABLE="Enabled";
       RWHOIS_NOTICESET="yes";;
    yes) echo "RWHOIS_NOTICE will be enabled.";
       RWHOIS_NOTICEENABLE="Enabled";
       RWHOIS_NOTICESET="yes";;
    Yes) echo "RWHOIS_NOTICE will be enabled.";
       RWHOIS_NOTICEENABLE="Enabled";
       RWHOIS_NOTICESET="yes";;
    YES) echo "RWHOIS_NOTICE will be enabled.";
       RWHOIS_NOTICEENABLE="Enabled";
       RWHOIS_NOTICESET="yes";;
    n) echo "RWHOIS_NOTICE will be disabled.";
       RWHOIS_NOTICEENABLE="Disabled";
       RWHOIS_NOTICESET="yes";;
    N) echo "RWHOIS_NOTICE will be disabled.";
       RWHOIS_NOTICEENABLE="Disabled";
       RWHOIS_NOTICESET="yes";;
    no) echo "RWHOIS_NOTICE will be disabled.";
       RWHOIS_NOTICEENABLE="Disabled";
       RWHOIS_NOTICESET="yes";;
    No) echo "RWHOIS_NOTICE will be disabled.";
       RWHOIS_NOTICEENABLE="Disabled";
       RWHOIS_NOTICESET="yes";;
    NO) echo "RWHOIS_NOTICE will be disabled.";
       RWHOIS_NOTICEENABLE="Disabled";
       RWHOIS_NOTICESET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$ADMINKICKEXEMPTSET" != "yes" ]
do
  echo ""
  echo "Enable ADMINKICKEXEMPT?"
  echo "Prevents Administrators from being kicked in channels."
  echo "Will only prevent local users from kicking admins remote"
  echo "or local to avoid desync."
  echo "Added by Michael P. Bramel for Hybrid-7+mpb"
  echo "Default: Enabled"
  read ADMINKICKEXEMPTCONFIRM
  if [ "$ADMINKICKEXEMPTCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    ADMINKICKEXEMPTCONFIRM="yes"
  fi
  case $ADMINKICKEXEMPTCONFIRM in
    y) echo "ADMINKICKEXEMPT will be enabled.";
       ADMINKICKEXEMPTENABLE="Enabled";
       ADMINKICKEXEMPTSET="yes";;
    Y) echo "ADMINKICKEXEMPT will be enabled.";
       ADMINKICKEXEMPTENABLE="Enabled";
       ADMINKICKEXEMPTSET="yes";;
    yes) echo "ADMINKICKEXEMPT will be enabled.";
       ADMINKICKEXEMPTENABLE="Enabled";
       ADMINKICKEXEMPTSET="yes";;
    Yes) echo "ADMINKICKEXEMPT will be enabled.";
       ADMINKICKEXEMPTENABLE="Enabled";
       ADMINKICKEXEMPTSET="yes";;
    YES) echo "ADMINKICKEXEMPT will be enabled.";
       ADMINKICKEXEMPTENABLE="Enabled";
       ADMINKICKEXEMPTSET="yes";;
    n) echo "ADMINKICKEXEMPT will be disabled.";
       ADMINKICKEXEMPTENABLE="Disabled";
       ADMINKICKEXEMPTSET="yes";;
    N) echo "ADMINKICKEXEMPT will be disabled.";
       ADMINKICKEXEMPTENABLE="Disabled";
       ADMINKICKEXEMPTSET="yes";;
    no) echo "ADMINKICKEXEMPT will be disabled.";
       ADMINKICKEXEMPTENABLE="Disabled";
       ADMINKICKEXEMPTSET="yes";;
    No) echo "ADMINKICKEXEMPT will be disabled.";
       ADMINKICKEXEMPTENABLE="Disabled";
       ADMINKICKEXEMPTSET="yes";;
    NO) echo "ADMINKICKEXEMPT will be disabled.";
       ADMINKICKEXEMPTENABLE="Disabled";
       ADMINKICKEXEMPTSET="yes";;
    *) echo "Invalid Selection: Please enter y to enable, or n to disable.";;
  esac
done
while [ "$ADMINKILLEXEMPTSET" != "yes" ]
do
  echo ""
  echo "Enable ADMINKILLEXEMPT?"
  echo "Prevents Administrators from being killed by Operators." 
  echo "Please note this only stops kills by operators on this" 
  echo "server, remote kills against local admins will not be"
  echo "stopped. A good way to /make sure/ your opers don't kill"
  echo "the really wrong people, the IRC network's administration."
  echo "Added by Michael P. Bramel for Hybrid-7+mpb"
  echo "Default: Enabled"
  read ADMINKILLEXEMPTCONFIRM
  if [ "$ADMINKILLEXEMPTCONFIRM" = "" ]; then
    echo "No option specified, setting default of: Enabled"
    ADMINKILLEXEMPTCONFIRM="yes"
  fi
  case $ADMINKILLEXEMPTCONFIRM in
  y) echo "ADMINKILLEXEMPT will be enabled.";
     ADMINKILLEXEMPTENABLE="Enabled";
     ADMINKILLEXEMPTSET="yes";;
  Y) echo "ADMINKILLEXEMPT will be enabled.";
     ADMINKILLEXEMPTENABLE="Enabled";
     ADMINKILLEXEMPTSET="yes";;
  yes) echo "ADMINKILLEXEMPT will be enabled.";
     ADMINKILLEXEMPTENABLE="Enabled";
     ADMINKILLEXEMPTSET="yes";;
  Yes) echo "ADMINKILLEXEMPT will be enabled.";
     ADMINKILLEXEMPTENABLE="Enabled";
     ADMINKILLEXEMPTSET="yes";;
  YES) echo "ADMINKILLEXEMPT will be enabled.";
     ADMINKILLEXEMPTENABLE="Enabled";
     ADMINKILLEXEMPTSET="yes";;
  n) echo "ADMINKILLEXEMPT will be disabled.";
     ADMINKILLEXEMPTENABLE="Disabled";
     ADMINKILLEXEMPTSET="yes";;
  N) echo "ADMINKILLEXEMPT will be disabled.";
     ADMINKILLEXEMPTENABLE="Disabled";
     ADMINKILLEXEMPTSET="yes";;
  no) echo "ADMINKILLEXEMPT will be disabled.";
     ADMINKILLEXEMPTENABLE="Disabled";
     ADMINKILLEXEMPTSET="yes";;
  No) echo "ADMINKILLEXEMPT will be disabled.";
     ADMINKILLEXEMPTENABLE="Disabled";
     ADMINKILLEXEMPTSET="yes";;
  NO) echo "ADMINKILLEXEMPT will be disabled.";
     ADMINKILLEXEMPTENABLE="Disabled";
     ADMINKILLEXEMPTSET="yes";;
  esac
done
echo ""
echo ""
echo "Will compile with the following settings:"
echo "Setting    ... Variable"
echo "SOURCE     ... $INSTALLSOURCE"
echo "PREFIX     ... $HYBRIDPATH"
echo "MAXCLIENTS ... $MAXIMUMCLIENTS"
echo ""
echo "Hybrid7 Option Status:"
echo "Setting             ... Variable"
echo "WANT_GETTEXT        ... $WANT_GETTEXTENABLE"
echo "IGNORE_BOGUS_TS     ... $IGNORE_BOGUS_TSENABLE"
echo "HIDE_SERVERS_IPS    ... $HIDE_SERVERS_IPSENABLE"
echo "HIDE_SPOOF_IPS      ... $HIDE_SPOOF_IPSENABLE"
echo "TS5_ONLY            ... $TS5_ONLYENABLE"
echo "USE_LOGFILE         ... $USE_LOGFILEENABLE"
echo "USE_SYSLOG          ... $USE_SYSLOGENABLE"
echo "SYSLOG_KILL         ... $SYSLOG_KILLENABLE"
echo "SYSLOG_SQUIT        ... $SYSLOG_SQUITENABLE"
echo "SYSLOG_CONNECT      ... $SYSLOG_CONNECTENABLE"
echo "SYSLOG_USERS        ... $SYSLOG_USERSENABLE"
echo "SYSLOG_OPER         ... $SYSLOG_OPERENABLE"
echo "LOG_FACILITY        ... $LOG_FACILITYSETTING"
echo "CRYPT_OPER_PASSWORD ... $CRYPT_OPER_PASSWORDENABLE"
echo "CLIENT_FLOOD        ... $CLIENT_FLOODSETTING"
echo ""
echo "+MPB Option Status:"
echo "Setting            ... Variable"
echo "ADMINOWNAGE        ... $ADMINOWNAGEENABLE"
echo "REPORT_ADMINOWNAGE ... $REPORT_ADMINOWNAGEENABLE"
echo "CHANNELSPY         ... $CHANNELSPYENABLE"
echo "ALLOWWILDTOPLEVEL  ... $ALLOWWILDTOPLEVELENABLE"
echo "ADMINSSEEALLCHANS  ... $ADMINSSEEALLCHANSENABLE"
echo "RWHOIS_NOTICE      ... $RWHOIS_NOTICEENABLE"
echo "ADMINKICKEXEMPT    ... $ADMINKICKEXEMPTENABLE"
echo "ADMINKILLEXEMPT    ... $ADMINKILLEXEMPTENABLE"
echo ""
echo "Do you wish to proceed?"
echo "Enter yes to proceed with the next step, or Control+C to abort."
read PRECONFIGUREPROCEED
case $PRECONFIGUREPROCEED in
  y) echo "";
     echo "Continuing with install...";;
  Y) echo "";
     echo "Continuing with install...";;
  yes) echo "";
     echo "Continuing with install...";;
  Yes) echo "";
     echo "Continuing with install...";;
  YES) echo "";
     echo "Continuing with install...";;
  n) echo "";
     echo "Aborting installation...";
     exit 1;;
  N) echo "";
     echo "Aborting installation..."; 
     exit 1;;
  no) echo "";
     echo "Aborting installation..."; 
     exit 1;;
  No) echo "";
     echo "Aborting installation..."; 
     exit 1;;
  NO) echo "";
     echo "Aborting installation..."; 
     exit 1;;
  *) echo "";
     echo "Please enter a valid answer: yes to continue, or no to abort.";;
esac
echo ""

# Step 2, now we build config.h

echo "Building Setup files"
echo "Building include/config.h"
cat include/config.h.pre >> include/config.h
echo "" >> include/config.h
if [ "$WANT_GETTEXTENABLE" = "Enabled" ]; then
  echo "/* WANT_GETTEXT - toggle gettext support." >> include/config.h
  echo " * NOTE: if configure doesn't detect gettext, this won't do anything." >> include/config.h
  echo " */" >> include/config.h
  echo "#define WANT_GETTEXT" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$WANT_GETTEXTENABLE" = "Disabled" ]; then
  echo "/* WANT_GETTEXT - toggle gettext support." >> include/config.h 
  echo " * NOTE: if configure doesn't detect gettext, this won't do anything." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  WANT_GETTEXT" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$IGNORE_BOGUS_TSENABLE" = "Enabled" ]; then
  echo "/* Ignore bogus timestamps from other servers. Yes this will desync" >> include/config.h
  echo " * the network, but it will allow chanops to resync with a valid non TS 0" >> include/config.h
  echo " *" >> include/config.h
  echo " * This should be enabled network wide, or not at all." >> include/config.h
  echo " */" >> include/config.h
  echo "#define IGNORE_BOGUS_TS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$IGNORE_BOGUS_TSENABLE" = "Disabled" ]; then
  echo "/* Ignore bogus timestamps from other servers. Yes this will desync" >> include/config.h
  echo " * the network, but it will allow chanops to resync with a valid non TS 0" >> include/config.h
  echo " *" >> include/config.h
  echo " * This should be enabled network wide, or not at all." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  IGNORE_BOGUS_TS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$HIDE_SERVERS_IPSENABLE" = "Enabled" ]; then
  echo "/* HIDE_SERVERS_IPS" >> include/config.h
  echo " *" >> include/config.h
  echo " * If this is undefined, opers will be unable to see servers ips and will be" >> include/config.h
  echo " * shown a masked ip, admins will be shown the real ip." >> include/config.h
  echo " *" >> include/config.h
  echo " * If this is defined, nobody can see a servers ip.  *This is a kludge*, it" >> include/config.h
  echo " * has the side effect of hiding the ips everywhere, including logfiles." >> include/config.h
  echo " *" >> include/config.h
  echo " * We recommend you leave this undefined, and just take care with who you" >> include/config.h
  echo " * give admin=yes; to." >> include/config.h
  echo " */" >> include/config.h
  echo "#define HIDE_SERVERS_IPS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$HIDE_SERVERS_IPSENABLE" = "Disabled" ]; then
  echo "/* HIDE_SERVERS_IPS" >> include/config.h
  echo " *" >> include/config.h
  echo " * If this is undefined, opers will be unable to see servers ips and will be" >> include/config.h
  echo " * shown a masked ip, admins will be shown the real ip." >> include/config.h
  echo " *" >> include/config.h
  echo " * If this is defined, nobody can see a servers ip.  *This is a kludge*, it" >> include/config.h
  echo " * has the side effect of hiding the ips everywhere, including logfiles." >> include/config.h
  echo " *" >> include/config.h
  echo " * We recommend you leave this undefined, and just take care with who you" >> include/config.h
  echo " * give admin=yes; to." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  HIDE_SERVERS_IPS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$HIDE_SPOOF_IPSENABLE" = "Enabled" ]; then
  echo "/* HIDE_SPOOF_IPS" >> include/config.h
  echo " *" >> include/config.h
  echo " * If this is undefined, opers will be allowed to see the real IP of spoofed" >> include/config.h
  echo " * users in /trace etc.  If this is defined they will be shown a masked IP." >> include/config.h
  echo " */" >> include/config.h" >> include/config.h
  echo "#define HIDE_SPOOF_IPS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$HIDE_SPOOF_IPSENABLE" = "Disabled" ]; then
  echo "/* HIDE_SPOOF_IPS" >> include/config.h
  echo " *" >> include/config.h 
  echo " * If this is undefined, opers will be allowed to see the real IP of spoofed" >> include/config.h
  echo " * users in /trace etc.  If this is defined they will be shown a masked IP." >> include/config.h
  echo " */" >> include/config.h" >> include/config.h
  echo "#undef  HIDE_SPOOF_IPS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$TS5_ONLYENABLE" = "Enabled" ]; then
  echo "/* TS5_ONLY" >> include/config.h
  echo " * " >> include/config.h
  echo " * If this is defined only TS5 servers may link to the network.  See" >> include/config.h
  echo " * doc/ts5.txt for more information.  If your network has old servers" >> include/config.h
  echo " * (hyb5, hyb6.0, +CSr) or hybserv you should NOT define this." >> include/config.h
  echo " */" >> include/config.h
  echo "#define TS5_ONLY" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$TS5_ONLYENABLE" = "Disabled" ]; then
  echo "/* TS5_ONLY" >> include/config.h
  echo " * " >> include/config.h
  echo " * If this is defined only TS5 servers may link to the network.  See" >> include/config.h
  echo " * doc/ts5.txt for more information.  If your network has old servers" >> include/config.h
  echo " * (hyb5, hyb6.0, +CSr) or hybserv you should NOT define this." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  TS5_ONLY" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$USE_LOGFILEENABLE" = "Enabled" ]; then
  echo "/* USE_LOGFILE - log errors and such to LPATH" >> include/config.h
  echo " * If you wish to have the server send 'vital' messages about server" >> include/config.h
  echo " * to a logfile, define USE_LOGFILE." >> include/config.h
  echo " */" >> include/config.h
  echo "#define USE_LOGFILE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$USE_LOGFILEENABLE" = "Disabled" ]; then
  echo "/* USE_LOGFILE - log errors and such to LPATH" >> include/config.h
  echo " * If you wish to have the server send 'vital' messages about server" >> include/config.h
  echo " * to a logfile, define USE_LOGFILE." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  USE_LOGFILE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$USE_SYSLOGENABLE" = "Enabled" ]; then
  echo "/* USE_SYSLOG - log errors and such to syslog()" >> include/config.h
  echo " * If you wish to have the server send 'vital' messages about server" >> include/config.h
  echo " * through syslog, define USE_SYSLOG. Only system errors and events critical" >> include/config.h
  echo " * to the server are logged although if this is defined with FNAME_USERLOG," >> include/config.h
  echo " * syslog() is used instead of the above file. It is not recommended that" >> include/config.h
  echo " * this option is used unless you tell the system administrator beforehand" >> include/config.h
  echo " * and obtain their permission to send messages to the system log files." >> include/config.h
  echo " */" >> include/config.h
  echo "#define USE_SYSLOG" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$USE_SYSLOGENABLE" = "Disabled" ]; then
  echo "/* USE_SYSLOG - log errors and such to syslog()" >> include/config.h
  echo " * If you wish to have the server send 'vital' messages about server" >> include/config.h
  echo " * through syslog, define USE_SYSLOG. Only system errors and events critical" >> include/config.h
  echo " * to the server are logged although if this is defined with FNAME_USERLOG," >> include/config.h
  echo " * syslog() is used instead of the above file. It is not recommended that" >> include/config.h
  echo " * this option is used unless you tell the system administrator beforehand" >> include/config.h
  echo " * and obtain their permission to send messages to the system log files." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  USE_SYSLOG" >> include/config.h
  echo "" >> include/config.h
fi
echo "#ifdef USE_SYSLOG" >> include/config.h
echo "/* SYSLOG_KILL SYSLOG_SQUIT SYSLOG_CONNECT SYSLOG_USERS SYSLOG_OPER" >> include/config.h
echo " * If you use syslog above, you may want to turn some (none) of the" >> include/config.h
echo " * spurious log messages for KILL,SQUIT,etc off." >> include/config.h
echo " */" >> include/config.h
if [ "$SYSLOG_KILLENABLE" = "Enabled" ]; then
  echo "#define SYSLOG_KILL     /* log all operator kills to syslog */" >> include/config.h
fi
if [ "$SYSLOG_KILLENABLE" = "Disabled" ]; then
  echo "#undef  SYSLOG_KILL     /* log all operator kills to syslog */" >> include/config.h
fi
if [ "$SYSLOG_SQUITENABLE" = "Enabled" ]; then
  echo "#define SYSLOG_SQUIT    /* log all remote squits for all servers to syslog */" >> include/config.h
fi
if [ "$SYSLOG_SQUITENABLE" = "Disabled" ]; then
  echo "#undef  SYSLOG_SQUIT    /* log all remote squits for all servers to syslog */" >> include/config.h
fi
if [ "$SYSLOG_CONNECTENABLE" = "Enabled" ]; then
  echo "#define SYSLOG_CONNECT  /* log remote connect messages for other all servs */" >> include/config.h
fi
if [ "$SYSLOG_CONNECTENABLE" = "Disabled" ]; then
  echo "#undef  SYSLOG_CONNECT  /* log remote connect messages for other all servs */" >> include/config.h
fi
if [ "$SYSLOG_USERSENABLE" = "Enabled" ]; then
  echo "#define SYSLOG_USERS    /* send userlog stuff to syslog */" >> include/config.h
fi
if [ "$SYSLOG_USERSENABLE" = "Disabled" ]; then
  echo "#undef  SYSLOG_USERS    /* send userlog stuff to syslog */" >> include/config.h
fi
if [ "$SYSLOG_OPERENABLE" = "Enabled" ]; then
  echo "#define SYSLOG_OPER     /* log all users who successfully become an Op */" >> include/config.h
fi
if [ "$SYSLOG_OPERENABLE" = "Disabled" ]; then
  echo "#undef  SYSLOG_OPER     /* log all users who successfully become an Op */" >> include/config.h
fi
if [ "$LOG_FACILITYENABLE" != "Disabled" ]; then
  echo "" >> include/config.h
  echo "/* LOG_FACILITY - facility to use for syslog()" >> include/config.h
  echo " * Define the facility you want to use for syslog().  Ask your" >> include/config.h
  echo " * sysadmin which one you should use." >> include/config.h
  echo " */" >> include/config.h
  echo "#define LOG_FACILITY $LOG_FACILITYSETTING" >> include/config.h
fi
if [ "$LOG_FACILITYENABLE" = "Disabled" ]; then
  echo "" >> include/config.h
  echo "/* LOG_FACILITY - facility to use for syslog()" >> include/config.h
  echo " * Define the facility you want to use for syslog().  Ask your" >> include/config.h
  echo " * sysadmin which one you should use." >> include/config.h
  echo " */" >> include/config.h
  echo "#define LOG_FACILITY $LOG_FACILITYSETTING" >> include/config.h
fi
echo "" >> include/config.h
echo "#endif /* USE_SYSLOG */" >> include/config.h
echo "" >> include/config.h
if [ "$CRYPT_OPER_PASSWORDENABLE" = "Enabled" ]; then
  echo "/* CRYPT_OPER_PASSWORD - use crypted oper passwords in the ircd.conf" >> include/config.h
  echo " * define this if you want to use crypted passwords for operators in your" >> include/config.h
  echo " * ircd.conf file." >> include/config.h
  echo " */" >> include/config.h
  echo "#define CRYPT_OPER_PASSWORD" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$CRYPT_OPER_PASSWORDENABLE" = "Disabled" ]; then
  echo "/* CRYPT_OPER_PASSWORD - use crypted oper passwords in the ircd.conf" >> include/config.h
  echo " * define this if you want to use crypted passwords for operators in your" >> include/config.h
  echo " * ircd.conf file." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  CRYPT_OPER_PASSWORD" >> include/config.h
  echo "" >> include/config.h
fi
echo "/* CLIENT_FLOOD - client excess flood threshold(in messages)" >> include/config.h
echo " * The number of messages that we can receive before we disconnect the" >> include/config.h
echo " * remote client..." >> include/config.h
echo " */" >> include/config.h
echo "#define CLIENT_FLOOD $CLIENT_FLOODSETTING" >> include/config.h
echo "" >> include/config.h
if [ "$ADMINOWNAGEENABLE" = "Enabled" ]; then
  echo "/* ADMINOWNAGE - Allows Administrators to join channels past channel modes such" >> include/config.h
  echo " * as bans, limits, invite only and keys." >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid7+mpb" >> include/config.h
  echo " * Not recommended on productions ervers." >> include/config.h
  echo " */" >> include/config.h
  echo "#define ADMINOWNAGE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINOWNAGEENABLE" = "Disabled" ]; then
  echo "/* ADMINOWNAGE - Allows Administrators to join channels past channel modes such" >> include/config.h
  echo " * as bans, limits, invite only and keys." >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid7+mpb" >> include/config.h
  echo " * Not recommended on productions ervers." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  ADMINOWNAGE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$REPORT_ADMINOWNAGEENABLE" = "Enabled" ]; then
  echo "/* REPORT_ADMINOWNAGE - Reports use(abuse) of ADMINOWNAGE functionality to other" >> include/config.h
  echo " * server operators. Option ADMINOWNAGE must be enabled for this to work." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " * Most certainly recommended for production servers that have elected to use ADMINOWNAGE" >> include/config.h
  echo " *" >> include/config.h
  echo " * Please note, if this is defined without ADMINOWNAGE being defined, problems" >> include/config.h
  echo " * shall arise. Heed my warning." >> include/config.h
  echo " */" >> include/config.h
  echo "#define REPORT_ADMINOWNAGE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$REPORT_ADMINOWNAGEENABLE" = "Disabled" ]; then
  echo "/* REPORT_ADMINOWNAGE - Reports use(abuse) of ADMINOWNAGE functionality to other" >> include/config.h
  echo " * server operators. Option ADMINOWNAGE must be enabled for this to work." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " * Most certainly recommended for production servers that have elected to use ADMINOWNAGE" >> include/config.h
  echo " *" >> include/config.h
  echo " * Please note, if this is defined without ADMINOWNAGE being defined, problems" >> include/config.h
  echo " * shall arise. Heed my warning." >> include/config.h   
  echo " */" >> include/config.h
  echo "#undef  REPORT_ADMINOWNAGE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$CHANNELSPYENABLE" = "Enabled" ]; then
  echo "/* CHANNELSPY - Toggles support for Administrators seeing channel join/part/kick info." >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid-7+mpb" >> include/config.h
  echo " * Not recommended on production servers." >> include/config.h
  echo " */" >> include/config.h
  echo "#define CHANNELSPY" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$CHANNELSPYENABLE" = "Disabled" ]; then
  echo "/* CHANNELSPY - Toggles support for Administrators seeing channel join/part/kick info." >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid-7+mpb" >> include/config.h
  echo " * Not recommended on production servers." >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  CHANNELSPY" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ALLOWWILDTOPLEVELENABLE" = "Enabled" ]; then
  echo "/* ALLOWWILDTOPLEVEL - If this is enabled, Hybrid will not require top level domains" >> include/config.h
  echo " * to be specified in mass messages from IRC Operators." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#define ALLOWWILDTOPLEVEL" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ALLOWWILDTOPLEVELENABLE" = "Disabled" ]; then
  echo "/* ALLOWWILDTOPLEVEL - If this is enabled, Hybrid will not require top level domains" >> include/config.h
  echo " * to be specified in mass messages from IRC Operators." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  ALLOWWILDTOPLEVEL" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINSSEEALLCHANSENABLE" = "Enabled" ]; then
  echo "/* ADMINSSEEALLCHANS - Toggle support for admins seeing all chans in list and whois" >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#define ADMINSSEEALLCHANS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINSSEEALLCHANSENABLE" = "Disabled" ]; then
  echo "/* ADMINSSEEALLCHANS - Toggle support for admins seeing all chans in list and whois" >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  ADMINSSEEALLCHANS" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$RWHOIS_NOTICEENABLE" = "Enabled" ]; then
  echo "/* RWHOIS_NOTICE - toggle support for seeing remote whois requests" >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#define RWHOIS_NOTICE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$RWHOIS_NOTICEENABLE" = "Disabled" ]; then
  echo "/* RWHOIS_NOTICE - toggle support for seeing remote whois requests" >> include/config.h
  echo " * Added by Michael P. Bramel for hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  RWHOIS_NOTICE" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINKICKEXEMPTENABLE" = "Enabled" ]; then
  echo "/* ADMINKICKEXEMPT - Prevents Administrators from being kicked in channels." >> include/config.h
  echo " * Highly experimental, but all testing of the feature proved positive." >> include/config.h
  echo " * Should work if the entire network has this piece of code, will only prevent" >> include/config.h
  echo " * local users from kicking admins (remote or local) to avoid desync." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " * Not recommended on production servers" >> include/config.h
  echo " */" >> include/config.h
  echo "#define ADMINKICKEXEMPT" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINKICKEXEMPTENABLE" = "Disabled" ]; then
  echo "/* ADMINKICKEXEMPT - Prevents Administrators from being kicked in channels." >> include/config.h
  echo " * Highly experimental, but all testing of the feature proved positive." >> include/config.h
  echo " * Should work if the entire network has this piece of code, will only prevent" >> include/config.h
  echo " * local users from kicking admins (remote or local) to avoid desync." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " * Not recommended on production servers" >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  ADMINKICKEXEMPT" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINKILLEXEMPTENABLE" = "Enabled" ]; then
  echo "/* ADMINKILLEXEMPT - Prevents Administrators from being killed by Operators" >> include/config.h
  echo " * Please note this only stops kills by operators on this server, remote kills" >> include/config.h
  echo " * against local admins will not be stopped. A good way to /make sure/ your opers" >> include/config.h
  echo " * don't kill the really wrong people, the IRC network's administration." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#define ADMINKILLEXEMPT" >> include/config.h
  echo "" >> include/config.h
fi
if [ "$ADMINKILLEXEMPTENABLE" = "Disabled" ]; then
  echo "/* ADMINKILLEXEMPT - Prevents Administrators from being killed by Operators" >> include/config.h
  echo " * Please note this only stops kills by operators on this server, remote kills" >> include/config.h
  echo " * against local admins will not be stopped. A good way to /make sure/ your opers" >> include/config.h
  echo " * don't kill the really wrong people, the IRC network's administration." >> include/config.h
  echo " * Added by Michael P. Bramel for Hybrid-7+mpb" >> include/config.h
  echo " */" >> include/config.h
  echo "#undef  ADMINKILLEXEMPT" >> include/config.h
  echo "" >> include/config.h
fi
echo "" >> include/config.h
cat include/config.h.post >> include/config.h
echo "include/config.h has been created."
echo ""
echo "Setup is ready to run the compile time configuration script"
echo "$INSTALLSOURCE/configure --prefix=$HYBRIDPATH --with-maxclients=$MAXIMUMCLIENTS"
echo "Do you wish to proceed? This may take several minutes."
read PROCEEDWITHCONFIGURE
case $PROCEEDWITHCONFIGURE in
  y) echo "Proceeding with configure";
     echo "";;
  Y) echo "Proceeding with configure";
     echo "";;
  yes) echo "Proceeding with configure";
     echo "";;
  Yes) echo "Proceeding with configure";
     echo "";;
  YES) echo "Proceeding with configure";
     echo "";;
  n) echo "Aborting installation...";
     echo "";
     exit 1;;
  N) echo "Aborting installation...";
     echo "";
     exit 1;;
  no) echo "Aborting installation...";
     echo "";
     exit 1;;
  No) echo "Aborting installation...";
     echo "";
     exit 1;;
  NO) echo "Aborting installation...";
     echo "";
     exit 1;;
  *) echo "";
     echo "Please enter a valid answer: yes to continue, or no to abort.";;
esac
$INSTALLSOURCE/configure --prefix=$HYBRIDPATH --with-maxclients=$MAXIMUMCLIENTS
if test -f help/Makefile
then
  echo ""
  echo "Congratulations, configure completed sucessfully... You are now ready to build Hybrid."
else
  echo ""
  echo "There was a problem with the configure script, please consult the INSTALL file."
  echo ""
  exit 1
fi
echo "Do you wish to proceed with make? This may take several minutes."
read PROCEEDWITHMAKE
case $PROCEEDWITHMAKE in
  y) echo "Proceeding with make";
     echo "";;
  Y) echo "Proceeding with make";
     echo "";;
  yes) echo "Proceeding with make";
     echo "";;
  Yes) echo "Proceeding with make";
     echo "";;
  YES) echo "Proceeding with make";
     echo "";;
  n) echo "Aborting installation...";
     echo "";
     exit 1;;
  N) echo "Aborting installation...";
     echo "";
     exit 1;;
  no) echo "Aborting installation...";
     echo "";
     exit 1;;
  No) echo "Aborting installation...";
     echo "";
     exit 1;;
  NO) echo "Aborting installation...";
     echo "";
     exit 1;;
  *) echo "";
     echo "Please enter a valid answer: yes to continue, or no to abort.";;
esac
echo ""
echo "Cleaning any stale binary files..."
make clean
echo ""
echo "Done cleaning stale files, now beginning to build ircd-hybrid-7+mpb"
echo ""
make
if test -e src/ircd
then
  echo ""
  echo "Build completed sucessfully."
else
  echo ""
  echo "There was a problem encountered building Hybrid, please read the included INSTALL file."
  echo ""
  exit 1
fi
echo ""
echo "Would you like to install the compiled binaries to $HYBRIDPATH now?"
echo "This may take several minutes..."
read PROCEEDWITHINSTALL
case $PROCEEDWITHINSTALL in
  y) echo "Proceeding with install";
     echo "";;
  Y) echo "Proceeding with install";
     echo "";;
  yes) echo "Proceeding with install";
     echo "";;
  Yes) echo "Proceeding with install";
     echo "";;
  YES) echo "Proceeding with install";
     echo "";;
  n) echo "Aborting installation...";
     echo "";
     exit 1;;
  N) echo "Aborting installation...";
     echo "";
     exit 1;;
  no) echo "Aborting installation...";
     echo "";
     exit 1;;
  No) echo "Aborting installation...";
     echo ""; 
     exit 1;;
  NO) echo "Aborting installation...";
     echo "";
     exit 1;; 
  *) echo "";
     echo "Please enter a valid answer: yes to continue, or no to abort.";;
esac
echo "Now running make install..."
make install
if test -e $HYBRIDPATH/bin/ircd
then
  echo ""
  echo "Contratulations, setup has completed compile and install sucessfully."
else
  echo ""
  echo "A problem was encountered during install, please view the included INSTALL file."
  exit 1
fi
echo ""
while [ "$CONFSETUPDONE" != "true" ]
do
  echo "Would you like to run the ConfSetup utility and create your ircd.conf now?"
  read CONFSETUPCONFIRM
  case $CONFSETUPCONFIRM in
    y) echo "Now starting the ConfSetup utility.";
       echo "";
       CONFSETUPDONE="true";;
    Y) echo "Now starting the ConfSetup utility.";
       echo "";
       CONFSETUPDONE="true";;
    yes) echo "Now starting the ConfSetup utility.";
       echo "";
       CONFSETUPDONE="true";;
    Yes) echo "Now starting the ConfSetup utility.";
       echo "";
       CONFSETUPDONE="true";;
    YES) echo "Now starting the ConfSetup utility.";
       echo "";
       CONFSETUPDONE="true";;
    n) echo "Skipping ConfSetup, setup will now exit.";
       echo "";
       exit 1;;
    N) echo "Skipping ConfSetup, setup will now exit.";
       echo "";
       exit 1;;
    no) echo "Skipping ConfSetup, setup will now exit.";
       echo "";
       exit 1;;
    No) echo "Skipping ConfSetup, setup will now exit.";
       echo "";
       exit 1;;
    NO) echo "Skipping ConfSetup, setup will now exit.";
       echo "";
       exit 1;;
    *) echo "Please enter a valid answer, y for yes or n for no";
       echo "";;
  esac
done
$INSTALLSOURCE/ConfSetup.sh
echo ""
echo "Done!"
echo ""
