/*
 *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
 *  Shows spoofed's user's ip in /whois to Administrators
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  realipinwhois.c,v 1.02 2002/12/25 4:39:00 PM mpb
 */
#include "stdinc.h"
#include "modules.h"
#include "hook.h"
#include "client.h"
#include "ircd.h"
#include "send.h"
#include "numeric.h"

int
show_notice(struct hook_mfunc_data *);

void
_modinit(void)
{
  hook_add_hook("doing_whois", (hookfn *)show_notice);
}

void
_moddeinit(void)
{
  hook_del_hook("doing_whois", (hookfn *)show_notice);
}

const char *_version = "$Revision: 1.01 $";

/* show a whois notice
   source_p does a /whois on client_p */
int
show_notice(struct hook_mfunc_data *data)
{
  if (MyConnect(data->source_p) && MyConnect(data->client_p) && IsIPSpoof(data->client_p) &&
      IsOper(data->source_p) && data->source_p->umodes & FLAGS_ADMIN) 
    {
      char ipaddr[HOSTIPLEN];
      inetntop(data->client_p->localClient->aftype, &IN_ADDR(data->client_p->localClient->ip), ipaddr, HOSTIPLEN);
      sendto_one(data->source_p, form_str(RPL_WHOISIP),
                 me.name, data->source_p->name, data->client_p->name,
                 IsOperAdmin(data->source_p) ? ipaddr : "255.255.255.255");
    }

  return 0;
}
